@@ -1,4 +1,4 @@
-from zinc_request_processor import ZincRequestProcessor
+from zinc_request_processor import ZincRequestProcessor, ZincError
 from format_price import format_price
 from getpass import getpass
 import sys
@@ -43,10 +43,10 @@ class ValidationHelpers(object):
     @classmethod
     def validate_boolean(klass):
         def validate(x):
-            if (x == "y" or x == "n"):
+            if (x == "y" or x == "n" or x == ""):
                 return True
             else:
-                print "You must enter either 'y' or 'n'"
+                print "You must enter either 'y', 'n', or nothing"
         return validate
 
     @classmethod
@@ -70,7 +70,7 @@ class ValidationHelpers(object):
 
 class ZincWizard(object):
     PROMPTS = {
-        "search_query": "What do you want to buy? (e.g. black boots)",
+        "search_query": "What do you want to buy? (e.g. black cup)",
         "select_product_name": "Here are your results. Please select a product to purchase.",
         "product_variants": "Please please enter a product URL.",
         "product_quantity": "How many would you like to purchase? (Default: 1)",
@@ -84,7 +84,7 @@ class ZincWizard(object):
             "password": "Please enter your Amazon password"
             },
         "shipping_address": {
-            "start_message": "\nNow we'd like to get your shipping information.",
+            "start_message": "\nNow we'd like to get your shipping information. Don't worry if you make a mistake,\nwe'll ask you to verify the correctness of your address so you can retype it if you'd like.",
             "end_message": "\nYou've finished entering your shipping address!"
             },
         "address": {
@@ -128,6 +128,7 @@ class ZincWizard(object):
         self.product_url = None
         self.security_code = None
         self.async_responses = {}
+        self.shipping_address = None
 
     def get_stored_data(self, filename):
         if os.path.isfile(filename):
@@ -143,12 +144,21 @@ class ZincWizard(object):
             return self.get_address(key)
         elif key == "billing_address":
             if self.prompt_boolean(self.PROMPTS[key]["start_message"]):
-                return self.response_data["shipping_address"]
+                return self.shipping_address
             else:
                 return self.get_address(key)
 
     def start(self):
         print WELCOME_BANNER
+        try:
+            self.start_interactive_session()
+        except ZincError as e:
+            print "\nUnfortunately there seemed to be an error"
+            print e
+            print "\nRestarting...\n"
+            self.start()
+
+    def start_interactive_session(self):
         self.get_product_name(self.response_data)
         self.get_product_variants(self.response_data)
         self.get_retailer_credentials(self.response_data)
